/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.framework;

import java.io.PrintStream;

/**
 *
 * @author Zdeněk Žamberský
 */
public class SimpleLogger {

    public PrintStream ps;
    public String prefix;

    public SimpleLogger(PrintStream ps) {
        this.ps = ps;
        this.prefix = "";
    }

    public SimpleLogger(PrintStream ps, String prefix) {
        this.ps = ps;
        setPrefix(prefix);
    }

    public SimpleLogger(PrintStream ps, String... prefixes) {
        this.ps = ps;
        setPrefixes(prefixes);
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix + ": ";
    }

    public void setPrefixes(String... prefixes) {
        prefix = "";
        for (String pfx : prefixes) {
            this.prefix += pfx + ": ";
        }
    }

    public String getLogPrefix() {
        return "INFO: " + prefix;
    }

    public void printLogPrefix() {
        ps.print(getLogPrefix());
    }

    public void print(String s) {
        ps.print(s);
    }

    public void println(String s) {
        ps.println(s);
    }

    public void log(String text) {
        ps.println(getLogPrefix() + text);
    }

    public void log(String... strings) {
        String string = "";
        for (String s : strings) {
            string += s + " ";
        }
        log(string);
    }

    public void log(int i) {
        log(Integer.toString(i));
    }

    public void err(String text) {
        ps.println("ERROR: " + prefix + text);
    }

}
